@@ -17,6 +17,8 @@ pygtk.require('2.0')
 import gtk
 import os
 import hildon
+import pango
+
 
 
 class GUI:
@@ -52,7 +54,7 @@ class GUI:
            hbox.pack_end(button_load, False, False, 0)
            scrolledwindow.add(textview)
         
-           window.connect("destroy", lambda w: gtk.main_hide())
+           #window.connect("destroy", lambda w: gtk.main_quit())
            self.textbuffer.connect("changed", self.edited)
            button_load.connect("clicked", self.load_file)
            self.button_save.connect("clicked", self.save_file)
@@ -119,6 +121,15 @@ class GUI:
         window.add(vbox)
         window.show_all()
         
+    def Test_Script(self, widget):
+        
+        messagedialog = gtk.MessageDialog(self.window, 0, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO, "Are You Sure You Want To RUN Your OptimizeN900 Script?")
+        response = messagedialog.run()
+        messagedialog.destroy()
+        
+        if response == gtk.RESPONSE_YES :
+            os.system("sh /usr/local/bin/OptimizeN900") 
+        
     def View_Script(self, widget):
         window = hildon.StackableWindow()
         window.set_title("Current Script")
@@ -156,9 +167,6 @@ class GUI:
             os.system( "sudo python '/home/opt/CON900/Restore'")
         elif response == gtk.RESPONSE_NO :
             pass
-            
-    #def Edit_Script(self, messagedialog):
-        #print ("icu")
                
     def delete_event(self, widget, event):
         os.system ("rm -Rf /home/findump.txt")
@@ -177,7 +185,7 @@ class GUI:
         
         aboutdialog = gtk.AboutDialog()        
         aboutdialog.set_name("CON900")
-        aboutdialog.set_version("0.0.8-6")
+        aboutdialog.set_version("0.0.8-7")
         aboutdialog.set_comments("This application was created to ease the customization of OptimizeN900 Script. It's coded in PyGTK.")
         aboutdialog.set_license("GNU LGPL 2.1")
         aboutdialog.set_website("humblecon900.garage.maemo.org")
@@ -196,8 +204,14 @@ class GUI:
         hbox.pack_start(vbox_right)
         
         
-        label = gtk.Label("OptimizeN900 Editor")
+        label = gtk.Label("OptimizeN900\nEditor")
+        label.modify_font(pango.FontDescription("tahoma 24"))
+        label.set_line_wrap(True)
         vbox_left.pack_start(label)
+        
+        button6 =gtk.Button("TEST")
+        button6.connect("clicked", self.Test_Script)
+        vbox_left.pack_start(button6)
 
         button1 = gtk.Button("Find")
         button1.connect("clicked", self.Find_Process)
@@ -205,7 +219,7 @@ class GUI:
 
 	button2 = gtk.Button("Edit")
         button2.connect("clicked", self.Edit_Script)
-        vbox_left.pack_end(button2)
+        vbox_right.pack_start(button2)
 
         button3 = gtk.Button("Restore")
         button3.connect("clicked", self.Restore_script)
@@ -213,7 +227,7 @@ class GUI:
 
 	button4 = gtk.Button("Quit")
 	button4.connect("clicked", lambda w: gtk.main_quit(os.system ("rm -Rf /home/findump.txt")))
-        vbox_right.pack_start(button4)
+        vbox_left.pack_end(button4)
         
         button5 = gtk.Button("View")
         button5.connect("clicked", self.View_Script)
